# Testum, `.テスト`, `.测试`, `.測試`, `.परीक्षा`, `.испытание`, `.테스트`, `‏.טעסט`, `‏.آزمایشی`, `.பரிட்சை`, `.δοκιμή`, `.δοκιμή`, `.δοκιμή`, `‏.إختبار`


> TODO: add more context to this folder (Emerson Rocha, 2021-04-13 20:13 UTC)

## PROTIPS (Professional tips)

### Name for "test"
- <https://en.wikipedia.org/wiki/.test>
- <https://www.iana.org/domains/root/db>
- <https://en.wikipedia.org/wiki/IDN_Test_TLDs>

- `.テスト`
  - ISO 639-3: `jpn`, https://iso639-3.sil.org/code/jpn
  - ISO 639-1: `ja`
- zho (Macrolanguage)
    - `.测试`
      - ISO 639-3: `???`, https://iso639-3.sil.org/code/zho
      - ISO 639-1: `zh`
      - ISO 15924: `Hans`
      - Wikipedia: <https://zh.wikipedia.org/zh-hans/%E6%B5%8B%E8%AF%95>
    - `.測試`
      - ISO 639-3: `???`,  https://iso639-3.sil.org/code/zho
      - ISO 639-1: `zh`
      - ISO 15924: `Hant`
      - Wikipedia: <https://zh.wikipedia.org/zh-hant/%E6%B5%8B%E8%AF%95>
- `.परीक्षा`
  - ISO 639-3: `hin`, https://iso639-3.sil.org/code/hin
  - ISO 639-1: `hi`
  - ISO 15924: `????`
- `.испытание`
  - ISO 639-3: `rus`, https://iso639-3.sil.org/code/rus
  - ISO 639-1: `ru`
  - ISO 15924: `Cyrl`
  - Wikipedia: <https://ru.wikipedia.org/wiki/%D0%98%D1%81%D0%BF%D1%8B%D1%82%D0%B0%D0%BD%D0%B8%D0%B5>
- `.테스트`
  - ISO 639-3: `kor`, https://iso639-3.sil.org/code/kor
  - ISO 639-1: `ko`
  - Wikipedia: <https://ko.wikipedia.org/wiki/%ED%85%8C%EC%8A%A4%ED%8A%B8>
- yid (Macrolanguage)
  - `‏.טעסט` **(RTL)**
    - ISO 639-3: `yid`, https://iso639-3.sil.org/code/yid
    - ISO 639-1: `yi`
    - ISO 15924: `????`
    - Wikipedia: <https://oc.wikipedia.org/wiki/%D7%98%D7%A2%D7%A1%D7%98.>
- fas (Macrolanguage)
  - `‏.آزمایشی`  **(RTL)**
    - ISO 639-3: `fas`, https://iso639-3.sil.org/code/fas
    - ISO 639-1: `fa`
    - ISO 15924: `????`
  - Wikipedia: ?
- `.பரிட்சை`
  - ISO 639-3: `tam`, https://iso639-3.sil.org/code/tam
  - ISO 639-1: `ta`
  - ISO 15924: `Taml`
  - Wikipedia: 
    - <https://oc.wikipedia.org/wiki/.%E0%AE%AA%E0%AE%B0%E0%AE%BF%E0%AE%9F%E0%AF%8D%E0%AE%9A%E0%AF%88>
    - <https://en.wikipedia.org/wiki/Tamil_script>
- `.δοκιμή`
  - ISO 639-3: `gre` (?), https://iso639-3.sil.org/code/gre
  - ISO 639-1: `el`
  - ISO 15924: `????`
  - Wikipedia: 
    - ?
    - https://en.wikipedia.org/wiki/Greek_alphabet
- `‏.إختبار`  **(RTL)**
  - ISO 639-3: `ara` (?), https://iso639-3.sil.org/code/ara
  - ISO 639-1: `ar`
  - ISO 15924: `Arab`
  - Wikipedia:
    - https://ar.wikipedia.org/wiki/%D8%AA%D8%AC%D8%B1%D8%A8%D8%A9
    - https://en.wikipedia.org/wiki/Arabic_script
